==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/bean/convert/CtDrawdistributeDrwgrpinfo2CtDrawrecycleDrwgrpinfo.java <==
package com.ejianc.business.dc.bean.convert;

import com.ejianc.business.dc.bean.DcDrawdistributeDrwgrpinfoEntity;
import com.ejianc.business.dc.bean.DcDrawrecycleDrwgrpinfoEntity;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Mappings;
import org.springframework.context.annotation.Primary;

@Mapper(componentModel = "spring")
@Primary
public abstract class CtDrawdistributeDrwgrpinfo2CtDrawrecycleDrwgrpinfo {


    @Mappings(value={
            @Mapping(target = "id",ignore = true),
            @Mapping(target = "tenantId",ignore = true),
            @Mapping(source = "drwgrpCode",target  = "drwgrpCode"),
            @Mapping(source = "drwgrpName",target = "drwgrpName"),
            @Mapping(source = "drwgrpVsn",target  = "drwgrpVsn")


    })
    public abstract DcDrawrecycleDrwgrpinfoEntity ctDrawdistributeDrwgrpinfoDto2CtDrawrecycleDrwgrpinfoDto(DcDrawdistributeDrwgrpinfoEntity ctDrawdistributeDrwgrpinfoDto);



    @Mappings(value={
            @Mapping(target = "id",ignore = true),
            @Mapping(target = "tenantId",ignore = true),
            @Mapping(source = "drwgrpCode",target  = "drwgrpCode"),
            @Mapping(source = "drwgrpName",target = "drwgrpName"),
            @Mapping(source = "paperFlag",target  = "paperFlag"),
            @Mapping(source = "num",target  = "num"),
    })
    public abstract DcDrawdistributeDrwgrpinfoEntity ctDrawrecycleDrwgrpinfoDto2CtDrawdistributeDrwgrpinfoDto(DcDrawrecycleDrwgrpinfoEntity ctDrawrecycleDrwgrpinfoDto);


}

==> ejc-ztpcdc-impl-3.0.0-20230829.023503-203-sources.jar: com/ejianc/business/dc/bean/convert/CtDrawdistributeDrwgrpinfo2CtDrawrecycleDrwgrpinfo.java <==
package com.ejianc.business.dc.bean.convert;

import com.ejianc.business.dc.bean.DcDrawdistributeDrwgrpinfoEntity;
import com.ejianc.business.dc.bean.DcDrawrecycleDrwgrpinfoEntity;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Mappings;
import org.springframework.context.annotation.Primary;

@Mapper(componentModel = "spring")
@Primary
public abstract class CtDrawdistributeDrwgrpinfo2CtDrawrecycleDrwgrpinfo {


    @Mappings(value={
            @Mapping(target = "id",ignore = true),
            @Mapping(target = "tenantId",ignore = true),
            @Mapping(source = "drwgrpCode",target  = "drwgrpCode"),
            @Mapping(source = "drwgrpName",target = "drwgrpName"),
            @Mapping(source = "drwgrpVsn",target  = "drwgrpVsn"),
            @Mapping(source = "id",target  = "drawdistributeDrwgrpinfoId")


    })
    public abstract DcDrawrecycleDrwgrpinfoEntity ctDrawdistributeDrwgrpinfoDto2CtDrawrecycleDrwgrpinfoDto(DcDrawdistributeDrwgrpinfoEntity ctDrawdistributeDrwgrpinfoDto);



    @Mappings(value={
            @Mapping(target = "id",ignore = true),
            @Mapping(target = "tenantId",ignore = true),
            @Mapping(source = "drwgrpCode",target  = "drwgrpCode"),
            @Mapping(source = "drwgrpName",target = "drwgrpName"),
            @Mapping(source = "paperFlag",target  = "paperFlag"),
            @Mapping(source = "num",target  = "num"),
    })
    public abstract DcDrawdistributeDrwgrpinfoEntity ctDrawrecycleDrwgrpinfoDto2CtDrawdistributeDrwgrpinfoDto(DcDrawrecycleDrwgrpinfoEntity ctDrawrecycleDrwgrpinfoDto);


}
